@@ -1,4 +1,4 @@
-use super::{AuthProvider, AuthResult};
+use super::{AuthProvider, AuthResult, authenticator::GatewayAuthError};
 use hyper::http::request::Parts;
 
 
@@ -8,12 +8,12 @@ pub struct NoAuthProvider {}
 impl AuthProvider for NoAuthProvider {
     fn update_config(&mut self, _update: crate::config::ConfigUpdate) {}
 
-    fn identify_client(&self, head: Parts, _service_id: &str) -> (Parts, Result<AuthResult, String>) {
+    fn identify_client(&self, head: Parts, _service_id: &str) -> Result<(Parts, AuthResult), GatewayAuthError> {
         let result = AuthResult {
             client_id: String::from(""),
             sla: String::from(""),
         };
-        (head, Ok(result))
+        Ok((head, result))
     }
 }
 
