@@ -10,8 +10,8 @@ mod weighted;
 
 
 pub use middleware::{Middleware, MiddlewareRequest, MiddlewareHandle, RequestContext, 
-    MwPreRequest, MwPreResponse, MwPostRequest, MwPostResponse,
-    middleware_chain, start_middleware};
+    MwPreRequest, MwPreResponse, MwPostRequest, MwPostResponse, MwNextAction,
+    middleware_chain, start_middleware, GatewayError};
 
 pub use upstream::UpstreamMiddleware;
 pub use rate_limit::RateLimitMiddleware;
